@@ -60,10 +60,10 @@ class WpSocketClient:
     _reader: asyncio.StreamReader
     _writer: asyncio.StreamWriter
 
-    def __init__(self, host: str, port: int, async_packets_handler, **kwds):
+    def __init__(self, host: str, port: int, **kwds):
         self.host = host
         self.port = port
-        self._async_receive_handler = async_packets_handler
+        self.async_receive_handler = None
         self._config = WpSocketConfig(
             kwds.pop('connection_timeout', _CONNECTION_DEFAULT_TIMEOUT),
             kwds.pop('read_timeout', _READ_DEFAULT_TIMEOUT),
@@ -141,7 +141,8 @@ class WpSocketClient:
             try:
                 packets = await asyncio.wait_for(self._receive_packet_queue.get(),
                                                  timeout=self._config.queue_wait_timeout)
-                await self._async_receive_handler(packets)
+                if self.async_receive_handler:
+                    await self.async_receive_handler(packets)
                 self._receive_packet_queue.task_done()
             except asyncio.TimeoutError:
                 continue
@@ -181,8 +182,8 @@ class WpSocketClient:
                     now = time.time()
                     send_interval = now - self._last_send_time
                     receive_interval = now - self._last_receive_time
-                    if send_interval > self._config.receive_packet_interval \
-                            and receive_interval > self._config.send_packet_interval:
+                    if send_interval > self._config.send_packet_interval \
+                            and receive_interval > self._config.receive_packet_interval:
                         self._writer.write(send_data.packet)
                         await self._writer.drain()
                         self._last_send_time = time.time()
@@ -226,7 +227,7 @@ class WpSocketClient:
         if not self.connected:
             return
         self.connected = False
-        if not self._loop.is_closed():
+        if not self._loop.is_closed() and self._writer:
             self._writer.close()
         self._loop.create_task(self.async_on_disconnected())
 
